@@ -1,6 +1,6 @@
 ## @namespace datafed.CLI
 # @brief Provides a high-level client interface to the DataFed server
-# 
+#
 # The DataFed CLI module provides a high-level, text-based client
 # interface for sending commands to, and receiving replies from, a DateFed
 # server. Comands are structured hierarchically, with sub-commands taking
@@ -413,6 +413,10 @@ def _cli(ctx,*args,**kwargs):
     global _verbosity
     global _verbosity_sticky
 
+    if ctx.invoked_subcommand == "gendoc":
+        ctx.invoke( _genDoc )
+        raise SystemExit()
+
     if _capi == None:
         _initialize(ctx.params)
 
@@ -427,11 +431,8 @@ def _cli(ctx,*args,**kwargs):
 @_cli.command(name='gendoc',hidden=True)
 @click.pass_context
 def _genDoc( ctx ):
-
     body = _genDocCmd( None, ctx, 0, recurse = False )
 
-    #body = _genDocHeader("General Usage",0) + "\n" + _cli.get_help( ctx.parent ) + "\n\n"
-
     for c in _cli.list_commands( ctx ):
         subcmd = _cli.get_command( _cli, c )
         if not subcmd.hidden:
@@ -474,15 +475,20 @@ def _genDocCmd( cmd, ctx, level, parname = None, recurse = True ):
         if rv is not None:
             opts.append(rv)
 
-    doc +=  "\n" + cmd.help + "\n\nUsage::\n\n    " 
+    doc +=  "\n" + cmd.help + "\n\nUsage::\n\n    "
     if cname == "Datafed":
         doc += "datafed"
     else:
-        doc += ctx.command_path 
-    doc += " " + " ".join(tmp) + "\n\nOptions:\n\n"
+        doc += ctx.command_path
+
+    #doc += " " + " ".join(tmp) + "\n\nOptions::\n\n"
+    doc += " " + " ".join(tmp) + "\n\nOptions:\n\n.. csv-table::\n"
+    doc += '    :class: table-no-hscroll\n'
+    doc += '    :header: "Option", "Description"\n\n'
 
     for o in opts:
-        doc += o[0] + "  " + o[1] + "\n"
+        doc += '    "' + o[0] + '","' + o[1] + '"\n'
+        #doc += o[0] + "  " + o[1] + "\n"
 
     doc += "\n"
 
@@ -511,7 +517,7 @@ def _wc( coll_id ):
     Set/print current working collection or path. 'ID' can be a collection ID, alias, user
     or project ID, listing index, previous collection ('-'), or path ('..','/','~'). 'cd' is
     an alias for the 'wc' command.
-    
+
     The 'wc' command can be used to switch to a different user or project context by either
     specifying a user/project ID/alias as the argument, or by specifying a collection ID/alias
     that is owned by another user or project. In either case, if permission is granted, the CLI
@@ -658,11 +664,11 @@ def _dataView( data_id, context ):
 @click.option("-T","--tags",type=str,required=False,help="Tags (comma separated list).")
 @click.option("-r","--raw-data-file",type=str,required=False,help="Globus path to raw data file (local or remote) to upload to new record. Default endpoint is used if none provided.")
 @click.option("-x","--extension",type=str,required=False,help="Override raw data file extension if provided (default is auto detect).")
-@click.option("-E","--external",is_flag=True,required=False,help="Raw data file is external to DataFed (unmanaged)") 
+@click.option("-E","--external",is_flag=True,required=False,help="Raw data file is external to DataFed (unmanaged)")
 @click.option("-m","--metadata",type=str,required=False,help="Inline metadata in JSON format. JSON must define an object type. Cannot be specified with --metadata-file option.")
-@click.option("-f","--metadata-file",type=str,required=False,help="Path to local metadata file containing JSON. JSON must define an object type. Cannot be specified with --metadata option.") 
-@click.option("-s","--schema",type=str,required=False,help="Set metadata schema id:version") 
-@click.option("-e","--schema-enforce",is_flag=True,required=False,help="Fail on metadata validation errors") 
+@click.option("-f","--metadata-file",type=str,required=False,help="Path to local metadata file containing JSON. JSON must define an object type. Cannot be specified with --metadata option.")
+@click.option("-s","--schema",type=str,required=False,help="Set metadata schema id:version")
+@click.option("-e","--schema-enforce",is_flag=True,required=False,help="Fail on metadata validation errors")
 @click.option("-p","--parent",type=str,required=False, help="Parent collection ID, alias, or listing index. Default is the current working collection.")
 @click.option("-R","--repository",type=str,required=False,help="Repository ID (managed data only). Uses default allocation if not specified.")
 @click.option("-D","--deps",multiple=True, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Dependencies (provenance). Use one '--deps' option per dependency and specify with a string consisting of the type of relationship ('der', 'comp', 'ver') follwed by ID/alias of the referenced record. Relationship types are: 'der' for 'derived from', 'comp' for 'a component of', and 'ver' for 'a new version of'.")
@@ -718,8 +724,8 @@ def _dataCreate( title, alias, description, tags, raw_data_file, extension, exte
 @click.option("-m","--metadata",type=str,required=False,help="Inline metadata in JSON format.")
 @click.option("-f","--metadata-file",type=str,required=False,help="Path to local metadata file containing JSON.")
 @click.option("-S","--metadata-set",is_flag=True,required=False,help="Set (replace) existing metadata with provided instead of merging.")
-@click.option("-s","--schema",type=str,required=False,help="Set metadata schema id:version") 
-@click.option("-e","--schema-enforce",is_flag=True,required=False,help="Fail on metadata validation errors") 
+@click.option("-s","--schema",type=str,required=False,help="Set metadata schema id:version")
+@click.option("-e","--schema-enforce",is_flag=True,required=False,help="Fail on metadata validation errors")
 @click.option("-A","--deps-add",multiple=True, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify dependencies to add by listing first the type of relationship ('der', 'comp', or 'ver') follwed by ID/alias of the target record. Can be specified multiple times.")
 @click.option("-R","--deps-rem",multiple=True, type=click.Tuple([click.Choice(['der', 'comp', 'ver']), str]),help="Specify dependencies to remove by listing first the type of relationship ('der', 'comp', or 'ver') followed by ID/alias of the target record. Can be specified multiple times.")
 @_global_context_options
@@ -865,6 +871,8 @@ def _data_batch_create( collection, file, context ):
 
     if collection:
         coll_id = _resolve_coll_id( collection, context )
+    else:
+        coll_id = None
 
     reply = _capi.dataBatchCreate( file, coll_id = coll_id, context = context )
     _generic_reply_handler( reply, _print_batch )
@@ -917,7 +925,7 @@ def _list( ctx, item_id, offset, count, context ):
 
     if  _id[:2] == "p/":
         if _capi.projectGetRole( _id ) == 0:
-            reply = _capi.sharesListItems( _id, offset = offset, count = count, context = context )
+            reply = _capi.sharedListItems( _id, offset = offset, count = count, context = context )
             if _output_mode == _OM_TEXT:
                 click.echo("Listing project shares:")
         else:
@@ -925,7 +933,7 @@ def _list( ctx, item_id, offset, count, context ):
             if _output_mode == _OM_TEXT:
                 click.echo("Listing project root:")
     elif  _id[:2] == "u/":
-        reply = _capi.sharesListItems( _id, offset = offset, count = count, context = context )
+        reply = _capi.sharedListItems( _id, offset = offset, count = count, context = context )
         if _output_mode == _OM_TEXT:
                 click.echo("Listing user shares:")
     else:
@@ -1126,7 +1134,7 @@ def _queryView( qry_id ):
 @click.option("--schema",type=str,help="Metadata schema ID")
 @click.option("--meta",type=str,help="Metadata expression")
 @click.option("--meta-err",is_flag=True,help="Metadata has validation errors")
-@click.option("--owner",type=str,help="Owninging user ID (only for public queries)")
+@click.option("--owner",type=str,help="Owning user ID (only for public queries)")
 @click.option("--creator",type=str,help="Creating user ID")
 @click.option("--from","time_from",help="Find from specified date/time (M/D/YYYY[,HH:MM])")
 @click.option("--to","time_to", help="Find up to specified date/time (M/D/YYYY[,HH:MM])")
@@ -1155,7 +1163,7 @@ def _queryCreate( title, coll_mode, coll, id, text, tag, schema, meta, meta_err,
 @click.option("--schema",type=str,help="Metadata schema ID")
 @click.option("--meta",type=str,help="Metadata expression")
 @click.option("--meta-err",is_flag=True,help="Metadata has validation errors")
-@click.option("--owner",type=str,help="Owninging user ID (only for public queries)")
+@click.option("--owner",type=str,help="Owning user ID (only for public queries)")
 @click.option("--creator",type=str,help="Creating user ID")
 @click.option("--from","time_from",help="Find from specified date/time (M/D/YYYY[,HH:MM])")
 @click.option("--to","time_to", help="Find up to specified date/time (M/D/YYYY[,HH:MM])")
@@ -1210,7 +1218,7 @@ def _queryExec( qry_id, offset, count ):
 @click.option("--schema",type=str,help="Metadata schema ID")
 @click.option("--meta",type=str,help="Metadata expression")
 @click.option("--meta-err",is_flag=True,help="Metadata has validation errors")
-@click.option("--owner",type=str,help="Owninging user ID (only for public queries)")
+@click.option("--owner",type=str,help="Owning user ID (only for public queries)")
 @click.option("--creator",type=str,help="Creating user ID")
 @click.option("--from","time_from",help="Find from specified date/time (M/D/YYYY[,HH:MM])")
 @click.option("--to","time_to", help="Find up to specified date/time (M/D/YYYY[,HH:MM])")
@@ -1357,9 +1365,9 @@ def _shares( users, projects ):
 
     # TODO - add project subject when projects shares are added
     if not users and not projects:
-        reply = _capi.sharesListOwners( True, True )
+        reply = _capi.sharedList( True, True )
     else:
-        reply = _capi.sharesListOwners( users, projects )
+        reply = _capi.sharedList( users, projects )
     _generic_reply_handler( reply, _print_listing )
 
 # =============================================================================
@@ -1626,7 +1634,7 @@ def _verbositySet(level):
     else:
         click.echo(_verbosity_sticky)
 
-        
+
 @_cli.command( name='help' )
 @click.argument("command", required=False, nargs=-1)
 @click.pass_context
@@ -1829,6 +1837,10 @@ def _print_data( message ):
         click.echo( "{:<15}{:<50}".format('Schema: ', dr.sch_id if dr.sch_id else '(none)' ))
         if dr.sch_id and dr.metadata:
             click.echo( "{:<15}{:<50}".format('Meta Errors: ', "Yes" if dr.md_err_msg else 'No' ))
+            if dr.md_err_msg and _verbosity == 2:
+                click.echo( "" )
+                _wrap_text( dr.md_err_msg, "", 2 )
+                click.echo( "" )
 
         click.echo( "{:<15}{:<50}\n".format('Owner: ', dr.owner[2:]) +
                     "{:<15}{:<50}\n".format('Creator: ', dr.creator[2:]) +
